'''
Defines L{AccAdapt.Adapter}s for objects in accessibility toolkits to the
L{AccAdapt.Interface}s declared in L{LSRInterfaces}. Subpackages contain 
adapters on a per toolkit basis. Adapters for toolkits that are not available
are not imported.

@author: Peter Parente
@organization: IBM Corporation
@copyright: Copyright (c) 2005, 2006 IBM Corporation
@license: Common Public License 1.0

All rights reserved. This program and the accompanying materials are made
available under the terms of the Common Public License v1.0 which accompanies
this distribution, and is available at
U{http://www.opensource.org/licenses/cpl1.0.php}
'''
try:
  from ATSPI import *
except ImportError, e:
  print 'AT-SPI adapters unavailable:', e